@@ -251,6 +251,11 @@ class ShellWidget(NamepaceBrowserWidget, HelpWidget, DebuggingWidget,
         Executes source or the input buffer, possibly prompting for more
         input.
         """
+        # Needed for cases where there is no kernel initialized but
+        # an execution is triggered like when setting initial configs.
+        # See spyder-ide/spyder#16896
+        if self.kernel_client is None:
+            return
         if self._executing:
             self._execute_queue.append((source, hidden, interactive))
             return
@@ -298,8 +303,9 @@ class ShellWidget(NamepaceBrowserWidget, HelpWidget, DebuggingWidget,
 
     def remote_set_cwd(self, cwd):
         """Get current working directory from kernel."""
-        self._cwd = cwd
-        self.sig_working_directory_changed.emit(self._cwd)
+        if cwd != self._cwd:
+            self._cwd = cwd
+            self.sig_working_directory_changed.emit(self._cwd)
 
     def set_bracket_matcher_color_scheme(self, color_scheme):
         """Set color scheme for matched parentheses."""
